@@ -127,7 +127,7 @@ class GeodesicEngine():
     def stopping_criterion(self, *x):
         return True
 
-    def set_stopping_criterion(self, expr):
+    def set_stopping_criterion(self, expr, exit_str = "none"):
         expr_s = sp.parse_expr(expr)
         free_symbols = list(expr_s.free_symbols-set(self.metric.x))
         check = True
@@ -139,7 +139,7 @@ class GeodesicEngine():
             def f(*xu):
                 return stopping_criterion(*xu, *self.metric.get_parameters_val())
 
-            self.stopping_criterion = f
+            self.stopping_criterion = StoppingCriterion(f, exit_str)
         else:
             raise TypeError("Unkwnown symbol {}".format(str(symbol)))
         
@@ -159,19 +159,30 @@ class GeodesicEngine():
         if verbose:
             time_start = time.perf_counter()
 
-        tau, xu = integrator.integrate(0, tauf, np.array([*geo.initial_x, *geo.initial_u]), h)
+        tau, xu, exit = integrator.integrate(0, tauf, np.array([*geo.initial_x, *geo.initial_u]), h)
                 
         if verbose:
             time_elapsed = (time.perf_counter() - time_start)
-            print("Integration time = {} s".format(time_elapsed))
+            print(f"Integration completed in {time_elapsed:.5} s with result '{exit}'")
 
         geo.tau = tau
         geo.x = np.stack(xu[:,:4])
         geo.u = np.stack(xu[:,4:])
+        geo.exit = exit
 
         if interpolate == True:
             geo.x_int = sp_int.interp1d(geo.tau, geo.x, axis = 0, kind = "cubic")
             geo.u_int = sp_int.interp1d(geo.tau, geo.u, axis = 0, kind = "cubic")        
     
     def set_integrator(self, integrator):
-        self.integrator = integrator
\ No newline at end of file
+        self.integrator = integrator
+    
+
+class StoppingCriterion:
+
+    def __init__(self, stopping_criterion, exit_str):
+        self.stopping_criterion = stopping_criterion
+        self.exit = exit_str
+    
+    def __call__(self, *geo):
+        return self.stopping_criterion(*geo)
